@@ -70,12 +70,14 @@ vlabels <- function(X, attrn = "label") {
     for (i in seq_along(X)) attr(X[[i]], attrn) <- NULL
   } else {
     if(length(X) != length(value)) stop("length(X) must match length(value)")
-    for (i in seq_along(value)) attr(X[[i]], attrn) <- value[i]
+    for (i in seq_along(value)) attr(X[[i]], attrn) <- value[[i]]
   }
   if(any(clx == "data.table")) return(alc(`oldClass<-`(X, clx)))
   `oldClass<-`(X, clx)
 }
 
+setLabels <- function(X, value, attrn = "label") `vlabels<-`(X, attrn, value)
+
 # Also slower on WDI !!
 # "vlabels2<-" <- function(X, attrn = "label", value) {
 #   names(value) <- NULL
@@ -128,9 +130,12 @@ add_stub <- function(X, stub, pre = TRUE) {
   X
 }
 
-rm_stub <- function(X, stub, pre = TRUE) {
+rm_stub <- function(X, stub, pre = TRUE, regex = FALSE, ...) {
   if(!is.character(stub)) return(X)
-  if(pre)
+  if(regex)
+    rmstubFUN <- function(x) {
+      gsub(stub, "", x, ...)
+    } else if(pre)
     rmstubFUN <- function(x) { # much faster than using sub!
       v <- startsWith(x, stub)
       x[v] <- substr(x[v], nchar(stub)+1L, 1000000L)
